local linedestui = {}

local _utils = commonapi.utils
local _log = _utils.logPrep("commonapi.ui2.LineDestination")
local _syncdata = commonapi._syncdata



--  uielements = require("commonapi2.ui2.LineDestination").getImportantWindowElements()


-- LineManager = api.gui.util.getById("lineManager.newLine"):getParent()


-- LineManagerEditorComp = LineManager:getLayout():getItem(1)
-- LineManager_LineEditorComp = LineManager:getLayout():getItem(1)

-- LineEditor = LineManager_LineEditorComp:getLayout():getItem(0)

-- LineEditorStationsTable = LineEditor:getLayout():getItem(0):getItem(0):getItem(1)
-- supports deleteall


-- RemoveAllStation = LineEditor:getLayout():getItem(0):getItem(0):getItem(2):getItem(1)

-- LineEditor_Settings = LineEditor:getLayout():getItem(0):getItem(1)



-- LineDepotFilter = LineManager:getLayout():getItem(0):getItem(2)

-- LineDepotFilter

-- LineList = LineDepotFilter:getLayout():getItem(0)



-- LineName = LineList:getItem(0, 0):getLayout():getItem(0):getLayout():getItem(1):getText()

local linesextradetails_sync =
	_syncdata.SyncObject:new(
	{
		key = "linesextradetails",
		data = {}
	}
)

local function get_linesextradetails()
	local linesextradetails = linesextradetails_sync:getDataOrInit({})

	if (linesextradetails.version ~= 1) then
		linesextradetails.lines = {}
		linesextradetails.version = 1
	end

	if (linesextradetails.lines == nil) then
		linesextradetails.lines = {}
	end
	return linesextradetails
end

local function get_linesextradetails_forLine(lineEntityId)
	local linesextradetails = get_linesextradetails()

	if (linesextradetails.lines[lineEntityId] == nil) then
		linesextradetails.lines[lineEntityId] = {}
	end
	local linedetails = linesextradetails.lines[lineEntityId]

	if (linedetails.endStations == nil) then
		linedetails.endStations = {}
	end
	return linedetails, linesextradetails
end


local detailsobj = {}

function detailsobj:createFor(lineId)
	--local o = o or {}
	if (lineId == nil) then
		print("Line ID missing!")
		return nil
	end
	local o = {
		lineId = lineId,
		linesextradetails = linesextradetails_sync:getDataOrInit({})
	}

	for k, v in pairs(self) do
		if (o[k] == nil) then
			o[k] = _utils.deepcopy(v)
		end
	end
	o._super = self
	return o
end



function detailsobj:verifyLineData()
	if (self.linesextradetails.lines[self.lineId] == nil) then
		return
	end

	_log("detailsobj:verifyLineData()")
	local linedetails = self.linesextradetails.lines[self.lineId]
	
	if (linedetails.endStations ~= nil) then
		if (next(linedetails.endStations) ~= nil) then
			local listOfStops, uniqueIdList = self:getLineStops()
			local remove = {}

			for key, _ in pairs(linedetails.endStations) do
				if (uniqueIdList[key] == nil) then
					remove[#remove+1] = key
				end
			end
			for i = 1, #remove do
				local key = remove[i]
				_log("Removing non existent stop from line", key)
				linedetails.endStations[key] = nil
			end
		end

		if (next(linedetails.endStations) == nil) then
			_log("detailsobj:verifyLineData() removing endStations")
			linedetails.endStations = nil
		end
	end
	if (next(self.linesextradetails.lines[self.lineId]) == nil) then
		_log("detailsobj:verifyLineData() removing lines", self.lineId)
		self.linesextradetails.lines[self.lineId] = nil
	end
end

function detailsobj:syncData()
	self:verifyLineData()

	linesextradetails_sync:syncData()
	self.linesextradetails = linesextradetails_sync:getData()
	if (commonapi._native.LabelSystem ~= nil) then
		commonapi._native.LabelSystem.updateData(self.linesextradetails)
	end
	commonapi_gamescript.saveData()
end



function detailsobj:getLineStops()
	local lineComp = api.engine.getComponent(self.lineId, api.type.ComponentType.LINE)
	if (lineComp == nil) then
		return nil
	end

	local entityVisited = {}
	local getEntityIdx = function(entityId)
		if (entityVisited[entityId] == nil) then
			entityVisited[entityId] = 1
		else
			entityVisited[entityId] = entityVisited[entityId] + 1
		end
		return entityVisited[entityId]
	end

	local listOfStops = {}
	local uniqueIdList = {}

	for stopIndex, stopData in ipairs(lineComp.stops) do
		local entityId = stopData.stationGroup
		local idx = getEntityIdx(entityId)
		local uniqueId = entityId..'-'..idx
		listOfStops[#listOfStops+1] = {
			id = entityId,
			idx = idx,
			uniqueId = uniqueId,
			lineId = self.lineId,
		}
		uniqueIdList[uniqueId] = true

		for waypointIndex, waypointEntity in ipairs(stopData.waypoints) do
			local idxW = getEntityIdx(waypointEntity)
			local uniqueIdW = waypointEntity..'-'..idxW
			listOfStops[#listOfStops+1] = {
				id = waypointEntity,
				idx = idxW,
				uniqueId = uniqueIdW,
				lineId = self.lineId,
				waypoint = true,
			}
			uniqueIdList[uniqueIdW] = true
		end
	end

	return listOfStops, uniqueIdList
end


function detailsobj:getEndStations()
	if (self.linesextradetails.lines == nil) then
		return nil
	end
	if (self.linesextradetails.lines[self.lineId] == nil) then
		return nil
	end
	local linedetails = self.linesextradetails.lines[self.lineId]
	return linedetails.endStations
end



function detailsobj:setEndStationData(uniqueId, data)
	if (self.linesextradetails.version ~= 1) then
		self.linesextradetails.version = 1
		self.linesextradetails.lines = {}
	end

	if (self.linesextradetails.lines[self.lineId] == nil) then
		self.linesextradetails.lines[self.lineId] = {}
	end

	local linedetails = self.linesextradetails.lines[self.lineId]

	if (linedetails.endStations == nil) then
		linedetails.endStations = {}
	end
	linedetails.endStations[uniqueId] = data
	self:syncData()
end



function detailsobj:getEndStationData(uniqueId)
	if (self.linesextradetails.lines == nil) then
		return nil
	end
	if (self.linesextradetails.lines[self.lineId] == nil) then
		return nil
	end
	local linedetails = self.linesextradetails.lines[self.lineId]
	if (linedetails.endStations == nil) then
		return nil
	end
	return linedetails.endStations[uniqueId]
end

function detailsobj:removeEndStationData(uniqueId)
	if (self.linesextradetails.lines[self.lineId] == nil) then
		return nil
	end
	local linedetails = self.linesextradetails.lines[self.lineId]
	if (linedetails.endStations ~= nil) then
		linedetails.endStations[uniqueId] = nil
	end
	self:syncData()
end



function linedestui.checkBoxSetSelected(ele, checked, emitsignal)
	local checkBoxName = "CheckboxOff"
	if (checked == true) then
		checkBoxName = "CheckboxOn"
	end
	ele:setName(checkBoxName)
	ele:setSelected(checked, emitsignal)
end

function linedestui.checkBoxGetSelected(ele)
	if (ele:getName() == "CheckboxOn") then
		return true
	end
	return false
end

function linedestui.getImportantWindowElements()
	local LineManagerNewLine = api.gui.util.getById("lineManager.newLine")
	if (LineManagerNewLine == nil) then
		return nil
	end
	local LineManager = LineManagerNewLine:getParent()


	local LineManagerLayout = LineManager:getLayout()


	local LineDepotFilter = LineManagerLayout:getItem(0):getItem(2)
	if (LineDepotFilter:getName() ~= "LineDepotFilter") then
		print("LineDepotFilter not found")
		return nil
	end

	local LineList = LineDepotFilter:getLayout():getItem(0)
	if (LineList:getName() ~= "Table") then
		print("LineList not found")
		return nil
	end

	local LineManager_LineEditorComp = LineManager:getLayout():getItem(1)
	if (LineManager_LineEditorComp:getName() ~= "LineManager::LineEditorComp") then
		print("LineManager::LineEditorComp not found")
		return nil
	end

	local LineEditor = LineManager_LineEditorComp:getLayout():getItem(0)
	if (LineEditor:getName() ~= "LineEditor") then
		print("LineEditor not found")
		return nil
	end
	local LineEditorStationsTable = LineEditor:getLayout():getItem(0):getItem(0):getItem(1)
	if (LineEditorStationsTable:getName() ~= "Table") then
		print("LineEditorStationsTable not found")
		return nil
	end



	local LineEditorSettings = LineEditor:getLayout():getItem(0):getItem(1)
	if (LineEditorSettings:getName() ~= "LineEditor::Settings") then
		print("LineEditor::Settings not found")
		return nil
	end

	--local LineDestText = api.
	local LayoutForSettings = LineEditorSettings:getLayout():getItem(1)

	local eleLineDest = api.gui.util.getById("LineDestination_Caption")
	if (eleLineDest == nil) then
		eleLineDest = api.gui.comp.TextView.new( _utils._t("Line Destination") )
		eleLineDest:setId("LineDestination_Caption")
		LayoutForSettings:addItem(eleLineDest)
	end


	local eleLineDestInfo = api.gui.util.getById("LineDestination_Info")
	if (eleLineDestInfo == nil) then
		eleLineDestInfo = api.gui.comp.TextView.new("<info>")
		eleLineDestInfo:setId("LineDestination_Info")
		LayoutForSettings:addItem(eleLineDestInfo)
	end


	local eleLineDestCheckbox = api.gui.util.getById("LineDestination_Checkbox")
	if (eleLineDestCheckbox == nil) then
		--eleLineDestCheckbox = api.gui.comp.CheckBox.new("Einschalten", "ui/checkbox0.tga", "ui/checkbox1.tga")
		eleLineDestCheckbox = api.gui.comp.CheckBox.new("Einschalten", "ui/onoff0.tga", "ui/onoff1.tga")
		eleLineDestCheckbox:setId("LineDestination_Checkbox")
		LayoutForSettings:addItem(eleLineDestCheckbox)

		local LineDestCheckboxToggleFn = function(checked)
			local checkBoxName = "CheckboxOff"
			if (checked == true) then
				checkBoxName = "CheckboxOn"
			end
			eleLineDestCheckbox:setName(checkBoxName)

			local curSelf = package.loaded["commonapi2.ui2.LineDestination"]
			if (curSelf ~= nil) then
				local ok, err = pcall(curSelf.LineDestCheckboxChangeEvent)
				if (ok == false) then
					print(err)
				end
			end
		end
		eleLineDestCheckbox:onToggle(LineDestCheckboxToggleFn)
	end


	local eleLineDestText = api.gui.util.getById("LineDestination_Text")
	if (eleLineDestText == nil) then
		eleLineDestText = api.gui.comp.TextInputField.new("")
		eleLineDestText:setId("LineDestination_Text")
		local LineLineDestTextChangeFn = function()
			local curSelf = package.loaded["commonapi2.ui2.LineDestination"]
			if (curSelf ~= nil) then
				local ok, err = pcall(curSelf.LineDestTextChangeEvent)
				if (ok == false) then
					print(err)
				end
			end
		end
		eleLineDestText:onEnter(LineLineDestTextChangeFn)
		LayoutForSettings:addItem(eleLineDestText)
	end




	local eleLineToVehicleManager = api.gui.util.getById("LineDestination_LineToVM")
	if (eleLineToVehicleManager == nil) then
		local eleLineToVehicleManagerText = api.gui.comp.TextView.new( _utils._t("Vehicles") )
		eleLineToVehicleManagerText:setName("ConfigureButton::Text")
		eleLineToVehicleManager = api.gui.comp.Button.new(eleLineToVehicleManagerText, true)
		eleLineToVehicleManager:setId("LineDestination_LineToVM")
		eleLineToVehicleManager:setName("ConfigureButton")
		local LineToVehicleManagerClickFn = function()
			local curSelf = package.loaded["commonapi2.ui2.LineDestination"]
			if (curSelf ~= nil) then
				local ok, err = pcall(curSelf.LineToVehicleManagerEvent)
				if (ok == false) then
					print(err)
				end
			end
		end
		eleLineToVehicleManager:onClick(LineToVehicleManagerClickFn)
		LayoutForSettings:addItem(eleLineToVehicleManager)
	end






	local uielements = {
		LineList = LineList,
		LineEditorStationsTable = LineEditorStationsTable,

		LineDestCaption = eleLineDest,
		LineDestInfo = eleLineDestInfo,
		LineDestCheckbox = eleLineDestCheckbox,
		LineDestText = eleLineDestText,


		LineToVehicleManager = eleLineToVehicleManager
	}

	linedestui.uielements = uielements
	return uielements
end



function linedestui.LineToVehicleManagerEvent()
	local uielements = linedestui.uielements or linedestui.getImportantWindowElements()
	if (uielements == nil) then
		return
	end

	local lineEntityId, err = linedestui.findSelectedLineEntityId(uielements)

	if (lineEntityId == nil) then
		return
	end

	local lineNameComp = api.engine.getComponent(lineEntityId, api.type.ComponentType.NAME)
	if (lineNameComp == nil) then
		return
	end
	local lineName = lineNameComp.name
	print("linename ",lineName)

	local VehicleManagerFilter = api.gui.util.getById("vehicleManager.buyVehicles"):getParent()
	local VehicleManagerFilterLayout = VehicleManagerFilter:getLayout()
	local VehicleManager = commonapi.ui._getParentWindowX(VehicleManagerFilter)
	VehicleManager:setVisible(true, true)

	local LineDepotFilter = VehicleManagerFilterLayout:getItem(2)

	local LineDepotFilterTableAlle = LineDepotFilter:getLayout():getItem(0)
	local LineDepotFilterTable = LineDepotFilter:getLayout():getItem(1)


	LineDepotFilterTableAlle:click()

	local numRows = LineDepotFilterTable:getNumRows()
	if (numRows > 0) then
		for i = 0, numRows-1 do
			local itemText = LineDepotFilterTable:getItem(i,1):getLayout():getItem(1)
			print(itemText:getText())
			if (itemText:getText() == lineName) then
				print("Trying to select")
				local itemCheckboxA = LineDepotFilterTable:getItem(i, 0)
--[[
				itemCheckboxA:setId("__temporaryCheckbox")
				local itemCheckbox = api.gui.util.getById("__temporaryCheckbox")
				itemCheckboxA:setId("")
--]]
				local itemCheckbox = api.gui.util.downcast(itemCheckboxA)
				itemCheckbox:setSelected(true, true)
			end
		end
	end
	

--	commonapi.ui.inspect(VehicleManager, "VehicleManagerWindow.txt")
-- api.gui.util.getById("vehicleManager.buyVehicles"):getParent():getParent():getParent():getParent():setId("")
end


function linedestui.LineStopListSelectEvent()
	local ok, err = pcall(linedestui.processSelectedLineEntity)
	if (ok == false) then
		print(err)
	end
end

function linedestui.LineListSelectEvent()
	local ok, err = pcall(linedestui.processSelectedLineEntity)
	if (ok == false) then
		print(err)
	end
end

function linedestui.LineDestCheckboxChangeEvent()
	local ok, err = pcall(linedestui.changeSelectedLineEntity, true)
	if (ok == false) then
		print(err)
	end
end

function linedestui.LineDestTextChangeEvent()
	local ok, err = pcall(linedestui.changeSelectedLineEntity, false)
	if (ok == false) then
		print(err)
	end
end


function linedestui.dataSync()
	--print("linedestui.dataSync()")
	local data = linesextradetails_sync:getData()
	linesextradetails_sync:syncData()

	commonapi.dmp(data)
	if (commonapi._native.LabelSystem ~= nil) then
		commonapi._native.LabelSystem.updateData(data)
	end
	commonapi_gamescript.saveData()
end

function linedestui.changeSelectedLineEntity(isCheckboxEvent)
	local uielements = linedestui.uielements or linedestui.getImportantWindowElements()
	if (uielements == nil) then
		return true
	end

	local stopData = linedestui.curselected
	if (stopData == nil) then
		return true
	end

	local text = uielements.LineDestText:getText()
	uielements.LineDestText:getText()
	local linedetails = detailsobj:createFor(stopData.lineId)
	
	local checkBoxSel = linedestui.checkBoxGetSelected(uielements.LineDestCheckbox)

	if (checkBoxSel == true or (text ~= "" and isCheckboxEvent ~= true) ) then
		linedestui.checkBoxSetSelected(uielements.LineDestCheckbox, true, false)
		linedetails:setEndStationData(stopData.uniqueId, {
			caption = text
		})
	else
		_log("Remove endStations",stopData.uniqueId)
		linedetails:removeEndStationData(stopData.uniqueId)
	end
	-- upgrades indicators:
	linedestui.findSelectedLineEntity(uielements)
	return true
end

function linedestui.processSelectedLineEntity()
	local uielements = linedestui.uielements or linedestui.getImportantWindowElements()
	if (uielements == nil) then
		_log("uielements empty")
		return true
	end
	local lineEntityId, stopData, linedetails = linedestui.findSelectedLineEntity(uielements)
	if (lineEntityId == nil or stopData == nil or linedetails == nil or stopData.waypoint == true) then
		uielements.LineDestInfo:setText(stopData or "")
		uielements.LineDestInfo:setVisible(true, false)
		uielements.LineDestCheckbox:setEnabled(false)

		linedestui.checkBoxSetSelected(uielements.LineDestCheckbox, false, false)

		uielements.LineDestText:setEnabled(false)
		uielements.LineDestText:setText("", false)

		return true
	else
		--local linedetails = get_linesextradetails_forLine(stopData.lineId)
		local destinationData = linedetails:getEndStationData(stopData.uniqueId) or {}
		uielements.LineDestInfo:setVisible(false, false)
		uielements.LineDestInfo:setText(stopData.lineId.." "..stopData.uniqueId)


		uielements.LineDestText:setEnabled(true)
		uielements.LineDestText:setText(destinationData.caption or "", false)

		uielements.LineDestCheckbox:setEnabled(true)
		linedestui.checkBoxSetSelected(uielements.LineDestCheckbox, destinationData.caption ~= nil, false)
	end
	return true
end

function linedestui.getLineFilterItem_ButtonComp(LineListItemLayout)
	local ButtonComp = LineListItemLayout:getItem(2)
	if (ButtonComp == nil or ButtonComp.getName == nil or ButtonComp:getName() ~= "LineFilterItem::ButtonComp") then
		return nil
	end
	return ButtonComp
end


function linedestui.alterLineFilterItem_ButtonComp(LineListItemLayout)
	local ButtonComp = linedestui.getLineFilterItem_ButtonComp(LineListItemLayout)
	if (ButtonComp == nil) then
		return
	end
	local ButtonCompLayout = ButtonComp:getLayout()
	local item1 = ButtonCompLayout:getItem(0)
	if (item1 ~= nil and item1:getName() ~= "Button2VM") then
		local tga = "ui/commonapi2button@2x.tga"
		local toVehicleManagerButtonIcon = api.gui.comp.ImageView.new(tga)
		toVehicleManagerButtonIcon:setName("Button:Icon")
		local toVehicleManagerButton = api.gui.comp.Button.new(toVehicleManagerButtonIcon, true)
		toVehicleManagerButton:setName("Button2VM")
		ButtonCompLayout:insertItem(toVehicleManagerButton, 0)
	end
end

function linedestui.alterLineFilterItem_ButtonCom(LineListItemLayout)

end



function linedestui.findSelectedLineEntityId(uielements)
	local LineList = uielements.LineList
	local LineListCurSelected = LineList:getSelected()
	local index = LineListCurSelected[1]
	if (index == nil) then
		local err = " index missing!"
		return nil, err
	end
	local LineListItemLayout = LineList:getItem(index, 0):getLayout()
	local lineNameSelected = LineListItemLayout:getItem(0):getLayout():getItem(1):getText()

	local lineEntityId = nil

	if (lineNameSelected ~= nil) then
		local lineIds = api.engine.system.lineSystem.getLines()
		for i = 1, #lineIds do
			local lineNameComp = api.engine.getComponent(lineIds[i], api.type.ComponentType.NAME)
			if (lineNameComp.name == lineNameSelected) then
				if (lineEntityId ~= nil) then
					local err = "Duplicate Line Name found!"
					return nil, err
				else
					lineEntityId = lineIds[i]
				end
			end
		end
	end
	if (lineEntityId == nil) then
		local err = "lineEntityId  missing!"
		return nil, err
	end

	return lineEntityId
end


function linedestui.findSelectedLineEntity(uielements)
	local LineList = uielements.LineList

	local LineEditorStationsTable = uielements.LineEditorStationsTable

	local LineListCurSelected = LineList:getSelected()
	local index = LineListCurSelected[1]

	linedestui.curselected = nil
	if (index == nil) then
		local err = " index missing!"
		return nil, err
	end

	local LineListItemLayout = LineList:getItem(index, 0):getLayout()
	local lineNameSelected = LineListItemLayout:getItem(0):getLayout():getItem(1):getText()
	--linedestui.alterLineFilterItem_ButtonComp(LineListItemLayout)


	
	local lineEntityId = nil

	if (lineNameSelected ~= nil) then
		local lineIds = api.engine.system.lineSystem.getLines()
		for i = 1, #lineIds do
			local lineNameComp = api.engine.getComponent(lineIds[i], api.type.ComponentType.NAME)
			if (lineNameComp.name == lineNameSelected) then
				if (lineEntityId ~= nil) then
					local err = "Duplicate Line Name found!"
					return nil, err
				else
					lineEntityId = lineIds[i]
				end
			end
		end
	end
	if (lineEntityId == nil) then
		local err = "lineEntityId  missing!"
		return nil, err
	end
	local lineComp = api.engine.getComponent(lineEntityId, api.type.ComponentType.LINE)

	if (lineComp == nil) then
		local err = "api.type.ComponentType.LINE for "..lineEntityId.." missing!"
		return nil, err
	end



	local linedetails = detailsobj:createFor(lineEntityId)
	local endStations = linedetails:getEndStations() or {}

	local indicatorCharByte1 = string.byte(" ")
	local patchStopCounterFn = function(counter, entityId, entityIdIdx, uniqueId)
		if (counter >= LineEditorStationsTable:getNumRows()) then
			return
		end
		local TableItem = LineEditorStationsTable:getItem(counter, 0)
		if (TableItem == nil) then
			return
		end

		local StopCounterLabelLayout = TableItem:getLayout()
		if (StopCounterLabelLayout == nil) then
			return
		end

		local StopCounterLabel = StopCounterLabelLayout:getItem(0)
		if (StopCounterLabel == nil) then
			return
		end
		local styleclass = "linestop-linedestination" --"big-error-message"

		local a = StopCounterLabel:getText()

		if ( endStations[ uniqueId ] ~= nil) then
			if (a and a:byte(1) ~= indicatorCharByte1) then
				StopCounterLabel:setText(' '..a)
				StopCounterLabel:addStyleClass(styleclass)
			end
		else
			if (a and a:byte(1) == indicatorCharByte1) then
				StopCounterLabel:setText(a:sub(2))
				if (StopCounterLabel.removeStyleClass) then
					StopCounterLabel:removeStyleClass(styleclass)
				end
			end
		end
	end

	local indicator = '>'
	local indicatorCharByte = string.byte(indicator)
	local patchStopCounterFn2 = function(counter, entityId, entityIdIdx, uniqueId)
		if (counter >= LineEditorStationsTable:getNumRows()) then
			return
		end
		local TableItem = LineEditorStationsTable:getItem(counter, 0)
		if (TableItem == nil) then
			return
		end

		local StopCounterLabelLayout = TableItem:getLayout()
		if (StopCounterLabelLayout == nil) then
			return
		end

		local StopCounterLabel = StopCounterLabelLayout:getItem(0)
		if (StopCounterLabel == nil) then
			return
		end

		local a = StopCounterLabel:getText()

		if ( endStations[ uniqueId ] ~= nil) then
			if (a and a:byte(1) ~= indicatorCharByte) then
				StopCounterLabel:setText('>'..a)
			end
		else
			local a = StopCounterLabel:getText()
			if (a and a:byte(1) == indicatorCharByte) then
				StopCounterLabel:setText(a:sub(2))
			end
		end
	end

	local listOfStops = linedetails:getLineStops() or {}
	for index, stopData in ipairs(listOfStops) do
		--commonapi.dmp(stopData)
		patchStopCounterFn(index-1, stopData.id, stopData.idx, stopData.uniqueId)
	end


	local possibleStopIndex = LineEditorStationsTable:getSelected()[1]

	if (possibleStopIndex == nil) then
		local err = _utils._t("Select a stop!")
		return nil, err
	end


--	commonapi.dmp(listOfStops)
--	print(possibleStopIndex)
--	commonapi.dmp(listOfStops[possibleStopIndex+1])
	local stopData = listOfStops[possibleStopIndex+1]
	linedestui.curselected = stopData
	return lineEntityId, stopData, linedetails
end



function linedestui.installHooks()
	local LineManagerNewLine = api.gui.util.getById("lineManager.newLine")

	if (LineManagerNewLine == nil) then
		_log("lineManager.newLine not found")
		return
	end

	_log("Preparing Hooks for LineDestination")

	local uilements = linedestui.getImportantWindowElements()
	if (uilements == nil) then
		_log("getImportantWindowElements failed")
		return
	end

	local LineList = uilements.LineList
	local LineListSelectFn = function(index)
		local curSelf = package.loaded["commonapi2.ui2.LineDestination"]
		if (curSelf ~= nil) then
			pcall(curSelf.LineListSelectEvent, index)
		end
	end
	LineList:onSelect(LineListSelectFn)

	local LineEditorStationsTable = uilements.LineEditorStationsTable
	local LineEditorStationsTableSelectFn = function(index)
		local curSelf = package.loaded["commonapi2.ui2.LineDestination"]
		if (curSelf ~= nil) then
			pcall(curSelf.LineStopListSelectEvent, index)
		end
	end
	LineEditorStationsTable:onSelect(LineEditorStationsTableSelectFn)

end


return linedestui